// ** React Imports
import React, {
    useState,
    useEffect,
    forwardRef,
    useCallback,
    Fragment,
} from "react";
import Icon from "@mdi/react";
import { mdiChevronRight, mdiClose } from "@mdi/js";

// ** MUI Imports
import Box from "@mui/material/Box";
import Drawer from "@mui/material/Drawer";
import Button from "@mui/material/Button";
import MenuItem from "@mui/material/MenuItem";
import TextField from "@mui/material/TextField";
import InputLabel from "@mui/material/InputLabel";
import Autocomplete from "@mui/material/Autocomplete";
import Typography from "@mui/material/Typography";
import FormControl from "@mui/material/FormControl";
import FormHelperText from "@mui/material/FormHelperText";
import Switch from "@mui/material/Switch";
import Select from "@mui/material/Select";
import FormControlLabel from "@mui/material/FormControlLabel";
import { CircularProgress } from "@mui/material";
import { useDropzone } from "react-dropzone";

// ** Third Party Imports
import DatePicker from "react-datepicker";
import { useForm, Controller } from "react-hook-form";
import { router, usePage } from "@inertiajs/react";

// ** Icons Imports
import Close from "mdi-material-ui/Close";
// import DeleteOutline from "mdi-material-ui/DeleteOutline";
// import InputError from "@/Components/InputErrorCustom";
import DatePickerWrapper from "@/Components/react-datepicker";
// ** Styled Components
import "react-datepicker/dist/react-datepicker.css";

const capitalize = (string) =>
    string && string[0].toUpperCase() + string.slice(1);

var date = new Date();
date.setDate(date.getDate() + 30);
// Format the result as a string (e.g., "YYYY-MM-DD")
const year = date.getFullYear();
const month = String(date.getMonth() + 1).padStart(2, "0");
const day = String(date.getDate()).padStart(2, "0");
const futureDate = `${year}-${month}-${day}`;

const nextDay = new Date(new Date().getTime() + 24 * 60 * 60 * 1000);

const nextMonth =
    date.getMonth() == 9
        ? new Date(date.getFullYear() + 1, 0, 1)
        : new Date(date.getFullYear(), date.getMonth() + 1, 1);

const prevMonth =
    date.getMonth() == 9
        ? new Date(date.getFullYear() - 1, 0, 1)
        : new Date(date.getFullYear(), date.getMonth() - 1, 1);

//

const NewPackage = (props) => {
    const {
        currentItem,
        selectedEvent,
        drawerWidth,
        addEventSidebarOpen,
        handleAddEventSidebarToggle,
    } = props;
    // ** Props

    const { flash, cities, rental_types, vehicle_types, year, brands, model } =
        usePage().props;

    const [openProgress, setOpenProgress] = useState(false);

    const [selectedFile, setSelectedFile] = useState(undefined);
    const [selectedFile2, setSelectedFile2] = useState(undefined);
    const [preview, setPreview] = React.useState("");
    const [preview2, setPreview2] = React.useState("");

    useEffect(() => {
        // console.log("currentMachine111", currentItem);
        // if (currentItem) console.log("currentItem", currentItem);
    }, [currentItem]);

    var defaultState = {
        name: "",
        title: "",
        no_of_days: "",
        no_of_night: "",
        description: "",
        starting_cost: "",
        cost_per_person: "",
        child_cost: "",
        max_people: "",
        tour_location: "",
        image_description: "",
        other_details: "",
        tour_plan: "",
        has_discount: 0,
        is_active: 1,
        no_of_people: "",
    };

    useEffect(() => {
        if (flash && flash.success) {
            setOpenProgress(false);
            // setOpenDialog(false);
        }
    }, [flash]);

    // ** States
    const [values, setValues] = useState(defaultState);

    const {
        control,
        setValue,
        clearErrors,
        handleSubmit,
        formState: { errors },
    } = useForm({ defaultValues: defaultState });

    const handleSidebarClose = async () => {
        setValues(defaultState);
        clearErrors();
        handleAddEventSidebarToggle();
    };

    const onSubmit = (data) => {
        setValues({
            ...values,
            image_full: selectedFile,
        });

        const listingData = {
            name: data.name,
            title: data.title,
            no_of_days: data.no_of_days,
            no_of_night: data.no_of_night,
            description: data.description,
            starting_cost: data.starting_cost,
            cost_per_person: data.cost_per_person,
            child_cost: data.child_cost,
            max_people: data.max_people,
            tour_location: data.tour_location,
            image_description: data.image_description,
            other_details: data.other_details,
            tour_plan: data.tour_plan,
            has_discount: data.has_discount,
            is_active: values.is_active,
            no_of_people: data.no_of_people,
            image: selectedFile,
        };

        setOpenProgress(true);
        // console.log("valuesss", listingData);
        // return;
        router.post(
            "/dashboard/add-packages",
            { ...listingData },
            {
                headers: {
                    "Content-Type": "multipart/form-data",
                },
            }
        );
    };

    const resetToStoredValues = useCallback(() => {}, [
        setValue,
        selectedEvent,
    ]);

    const resetToEmptyValues = useCallback(() => {
        setValue("title", "");
        setValues(defaultState);
    }, [setValue]);
    useEffect(() => {
        if (selectedEvent !== null) {
            resetToStoredValues();
        } else {
            resetToEmptyValues();
        }
    }, [
        addEventSidebarOpen,
        resetToStoredValues,
        resetToEmptyValues,
        selectedEvent,
    ]);

    const PickersComponent = forwardRef(({ ...props }, ref) => {
        return (
            <TextField
                inputRef={ref}
                fullWidth
                {...props}
                label={props.label || ""}
                sx={{ width: "100%" }}
                error={props.error}
            />
        );
    });

    const RenderSidebarFooter = () => {
        if (true) {
            return (
                <Fragment>
                    {!openProgress ? (
                        <Button
                            size="large"
                            type="submit"
                            variant="contained"
                            className="w-full"
                            sx={{ mr: 0 }}
                        >
                            Add
                        </Button>
                    ) : (
                        <Button
                            size="large"
                            variant="outlined"
                            className="w-full"
                            sx={{ mr: 0 }}
                        >
                            <CircularProgress className="text-main-500" />
                        </Button>
                    )}
                </Fragment>
            );
        }
    };

    const onDrop = React.useCallback((acceptedFiles) => {
        setSelectedFile(acceptedFiles[0]);
    }, []);

    useEffect(() => {
        if (!selectedFile) {
            setPreview(undefined);
            return;
        }

        const objectUrl = URL.createObjectURL(selectedFile);
        setPreview(objectUrl);

        return () => URL.revokeObjectURL(objectUrl);
    }, [selectedFile]);

    const { getRootProps, getInputProps, isDragActive } = useDropzone({
        accept: {
            "image/jpeg": [],
            "image/png": [],
            "image/gif": [],
            "image/webp": [],
        },
        onDrop,
    });

    return (
        <Drawer
            anchor="right"
            open={addEventSidebarOpen}
            onClose={handleSidebarClose}
            ModalProps={{ keepMounted: true }}
            sx={{ "& .MuiDrawer-paper": { width: ["100%", drawerWidth] } }}
        >
            <Box
                className="sidebar-header"
                sx={{
                    display: "flex",
                    justifyContent: "space-between",
                    backgroundColor: "background.default",
                    p: (theme) => theme.spacing(3, 3.255, 3, 5.255),
                }}
            >
                <Typography variant="h6">
                    {selectedEvent !== null
                        ? "ADD NEW PACKAGE"
                        : "ADD NEW PACKAGE"}
                </Typography>
                <Box sx={{ display: "flex", alignItems: "center" }}>
                    {selectedEvent !== null ? (
                        // <DeleteOutline
                        //     fontSize="small"
                        //     sx={{
                        //         cursor: "pointer",
                        //         mr: selectedEvent !== null ? 2 : 0,
                        //     }}
                        //     onClick={handleDeleteEvent}
                        // />
                        <></>
                    ) : null}
                    <Close
                        fontSize="small"
                        className="text-red-500"
                        onClick={handleSidebarClose}
                        sx={{ cursor: "pointer" }}
                    />
                </Box>
            </Box>
            <Box
                className="sidebar-body"
                sx={{ p: (theme) => theme.spacing(5, 6) }}
            >
                <DatePickerWrapper>
                    <form onSubmit={handleSubmit(onSubmit)} autoComplete="off">
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="name"
                                control={control}
                                rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Package Name"
                                        value={value}
                                        onChange={onChange}
                                        error={Boolean(errors.name)}
                                    />
                                )}
                            />
                            {errors.name && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="title"
                                control={control}
                                rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="title"
                                        multiline
                                        value={value}
                                        onChange={onChange}
                                        error={Boolean(errors.title)}
                                    />
                                )}
                            />
                            {errors.title && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="no_of_days"
                                control={control}
                                rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="No oF Days"
                                        value={value}
                                        onChange={onChange}
                                        error={Boolean(errors.no_of_days)}
                                    />
                                )}
                            />
                            {errors.no_of_days && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="no_of_night"
                                control={control}
                                // rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="No Of Nights"
                                        value={value}
                                        type={"number"}
                                        onChange={onChange}
                                        error={Boolean(errors.no_of_night)}
                                    />
                                )}
                            />
                            {errors.no_of_night && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="description"
                                control={control}
                                // rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Package description"
                                        value={value}
                                        rows={6}
                                        multiline
                                        onChange={onChange}
                                        error={Boolean(errors.description)}
                                    />
                                )}
                            />
                            {errors.description && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="starting_cost"
                                control={control}
                                // rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Starting Cost"
                                        value={value}
                                        type={"number"}
                                        onChange={onChange}
                                        error={Boolean(errors.starting_cost)}
                                    />
                                )}
                            />
                            {errors.starting_cost && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="max_people"
                                control={control}
                                // rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Max People"
                                        value={value}
                                        type={"number"}
                                        onChange={onChange}
                                        error={Boolean(errors.max_people)}
                                    />
                                )}
                            />
                            {errors.max_people && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        {/* <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="tour_location"
                                control={control}
                                rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Tour Location"
                                        value={value}
                                        onChange={onChange}
                                        error={Boolean(errors.tour_location)}
                                    />
                                )}
                            />
                            {errors.tour_location && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl> */}
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <InputLabel id="tour_location">Location</InputLabel>
                            <Select
                                label="Location"
                                value={values.tour_location}
                                labelId="tour_location"
                                onChange={(e) =>
                                    setValues({
                                        ...values,
                                        tour_location: e.target.value,
                                    })
                                }
                            >
                                <MenuItem value="Tanzania">Tanzania</MenuItem>
                                <MenuItem value="Kenya">Kenya</MenuItem>
                                <MenuItem value="Uganda">Uganda</MenuItem>
                                <MenuItem value="Rwanda">Rwanda</MenuItem>
                            </Select>
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="image_description"
                                control={control}
                                // rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Image Description"
                                        value={value}
                                        rows={6}
                                        multiline
                                        onChange={onChange}
                                        error={Boolean(
                                            errors.image_description
                                        )}
                                    />
                                )}
                            />
                            {errors.image_description && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="tour_plan"
                                control={control}
                                rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Tour Plan"
                                        value={value}
                                        rows={6}
                                        multiline
                                        onChange={onChange}
                                        error={Boolean(errors.tour_plan)}
                                    />
                                )}
                            />
                            {errors.tour_plan && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl sx={{ mb: 4 }}>
                            <FormControlLabel
                                label={"Has Discount?"}
                                control={
                                    <Switch
                                        checked={values.has_discount}
                                        onChange={(e) =>
                                            setValues({
                                                ...values,
                                                has_discount: e.target.checked,
                                            })
                                        }
                                    />
                                }
                            />
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="cost_per_person"
                                control={control}
                                // rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Cost Per Person"
                                        type="number"
                                        value={value}
                                        onChange={onChange}
                                        error={Boolean(errors.cost_per_person)}
                                    />
                                )}
                            />
                            {errors.cost_per_person && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 4 }}>
                            <Controller
                                name="child_cost"
                                control={control}
                                // rules={{ required: true }}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Child cost"
                                        type="number"
                                        value={value}
                                        onChange={onChange}
                                        error={Boolean(errors.child_cost)}
                                    />
                                )}
                            />
                            {errors.child_cost && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 2 }}>
                            <Controller
                                name="no_of_people"
                                control={control}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="No Of People"
                                        value={value}
                                        type={"number"}
                                        onChange={onChange}
                                        error={Boolean(errors.no_of_people)}
                                    />
                                )}
                            />
                            {errors.no_of_people && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <FormControl fullWidth sx={{ mb: 2 }}>
                            <Controller
                                name="other_details"
                                control={control}
                                render={({ field: { value, onChange } }) => (
                                    <TextField
                                        label="Other Details"
                                        rows={4}
                                        multiline
                                        value={value}
                                        onChange={onChange}
                                        error={Boolean(errors.other_details)}
                                        helperText="(if any)"
                                    />
                                )}
                            />
                            {errors.other_details && (
                                <FormHelperText
                                    sx={{ color: "error.main" }}
                                    id="event-title-error"
                                >
                                    This field is required
                                </FormHelperText>
                            )}
                        </FormControl>
                        <div className="flex justify-center pt-0 bg-second-500 px-8 text-gray-700">
                            <div className="mb-4">
                                <Typography
                                    variant="p"
                                    component="div"
                                    gutterBottom
                                    className="text-center"
                                >
                                    Package Image
                                </Typography>

                                <div className="">
                                    {selectedFile ? (
                                        <div className="w-48 relative my-4 border-dashed border-gray-600 border p-4">
                                            <img
                                                src={preview}
                                                className="object-cover w-40 h-40"
                                            />
                                            <div className="absolute top-2 right-2 bg-gray-300">
                                                <Icon
                                                    path={mdiClose}
                                                    size={1}
                                                    onClick={() => {
                                                        setSelectedFile(
                                                            undefined
                                                        );
                                                    }}
                                                />
                                            </div>
                                        </div>
                                    ) : (
                                        <div
                                            className="w-full my-4 h-40 border-dashed border-gray-500 border p-4"
                                            {...getRootProps()}
                                        >
                                            <input
                                                name="image"
                                                {...getInputProps()}
                                                // onChange={(e, val) => {
                                                // console.log(
                                                //     event.currentTarget
                                                //         .files[0]
                                                // );
                                                // setValues({
                                                //     ...values,
                                                //     image_full: e.target.value,
                                                // });
                                                // }}
                                            />
                                            {isDragActive ? (
                                                <p>Drop the files here ...</p>
                                            ) : (
                                                <p>
                                                    Click or drag and drop to
                                                    add image
                                                </p>
                                            )}
                                        </div>
                                    )}
                                </div>
                            </div>
                        </div>
                        <Box sx={{ display: "flex", alignItems: "center" }}>
                            <RenderSidebarFooter />
                        </Box>
                    </form>
                </DatePickerWrapper>
            </Box>
        </Drawer>
    );
};

export default NewPackage;
